package nl.piraya.blog;

import com.lowagie.text.pdf.FdfReader;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.HashMap;
import java.util.Set;

/**
 * Servlet that accepts POSTing binary FDF data. The form data will be parsed and the results outputted to System.out.
 *
 * @author Onno Scheffers
 */
public class FDFServlet extends HttpServlet {
   /**
    * Handles the POST to this servlet.
    *
    * @param request An {@link HttpServletRequest} object that contains the request the client has made of the servlet.
    * @param response An {@link HttpServletResponse} object that contains the response the servlet sends to the client.
    * @exception IOException If an input or output error is detected when the servlet handles the POST request.
    * @exception ServletException If the request for the POST could not be handled.
    */
   protected void doPost(
         final HttpServletRequest request,
         final HttpServletResponse response
   ) throws ServletException, IOException {

      // Check if we are getting FDF data
      String contentType = request.getContentType();
      if("application/vnd.fdf".equalsIgnoreCase(contentType)) {
         try {
            // Parse the FDF data using iText
            FdfReader reader = new FdfReader(request.getInputStream());
            HashMap map = reader.getFields();
            Set keys = map.keySet();
            for(Object key : keys) {
               // Simply output the keys and their values to System.out
               String value = reader.getFieldValue(key.toString());
               System.out.println(key + " = " + value);
            }
            reader.close();

            // Forward the user to the next page in the application
            // If you want to keep the user in the same PDF instead, you can simply return the FDF data you received
            response.sendRedirect("done.jsp");

            return;
         } catch (Exception e) {
            // Ignore
         }
      }
      throw new IOException("Unable to read FDF data from request");
   }
}
